clear all
close all
home

%%%Example MATLAB code that demonstrates how to plot mean Absorbance, Zmag,
%%%and Zang while incorporating the use of the subjects table by splitting
%%%the data by sex

%load in tables from database via MySQL
data = readtable('wai_measurements.csv');
Subjects_Table = readtable('wai_subjects.csv');


%only use PI we are checking
PI = 'Rosowski_2012';
data=data(strcmp(data.Identifier, PI),:);
Subjects_Table = Subjects_Table(strcmp(Subjects_Table.Identifier, PI),:);

%get frequencies and subject numbers
Frequency = unique(data.Frequency);
SubjectNumbers=unique(data.SubjectNumber);
NumberSubjects=length(SubjectNumbers);

%make sure number of subjects is correct from subjects table (should be 29)
NumSubs = length(unique(Subjects_Table.SubjectNumber)); %it's 29, so it's correct


%get female and male subject numbers
femalesubject_rows = find(strcmp(Subjects_Table.Sex, 'Female'));
femalesubject_data = Subjects_Table(femalesubject_rows,:);
femalesubjectnums = femalesubject_data(:,2); %the subject numbers are in the second column of the table
femalesubjectnums = table2array(femalesubjectnums);

malesubject_rows = find(strcmp(Subjects_Table.Sex, 'Male  '));
malesubject_data = Subjects_Table(malesubject_rows,:);
malesubjectnums = malesubject_data(:,2);
malesubjectnums = table2array(malesubjectnums);

%%%get the mean absorbance for male and female subjects
Absorbance_Female = [];
Absorbance_Male = [];
%loop through all the subjects
for index=1:length(SubjectNumbers)
    SubNumForLoop = SubjectNumbers(index);
    %get the rows of the subject in the table
    sub_row = find(data.SubjectNumber == SubNumForLoop);
    %create a table of the subject's data each loop
    Subject_Data = data(sub_row,:);
    
    %if the subject number is in the list of female subject numbers, get
    %the female subject's data
    if sum(femalesubjectnums==SubNumForLoop) == 1
        AbsorbanceSub_Female = [];
        %loop through the frequencies in the data 
        for freq_indexF=1:length(Frequency)
            %get the frequency every loop
            FreqForLoopF = Frequency(freq_indexF);
            %get the rows in the subject's data that have that frequency
            freq_rowF = find(Subject_Data.Frequency == FreqForLoopF);
            %create an array of the absorbance data for the subject in this
            %loop (2 sets of absorbance data for each subject because there
            %is data for the left and right ear)
        AbsorbanceSub_Female = [AbsorbanceSub_Female; Subject_Data.Absorbance(freq_rowF).'];
        end
        %create an array of all the absorbance data for all the female subjects
        Absorbance_Female = [Absorbance_Female; AbsorbanceSub_Female.'];
        
    %if the subject number is in the list of male subject numbers, get
    %the male subject's data
    elseif sum(malesubjectnums==SubNumForLoop) == 1
        AbsorbanceSub_Male = [];
        %loop through the frequencies in the data
        for freq_indexM=1:length(Frequency)
            %get the frequency every loop
            FreqForLoopM = Frequency(freq_indexM);
            %get the rows in the subject's data that have that frequency
            freq_rowM = find(Subject_Data.Frequency == FreqForLoopM);
            %create an array of the absorbance data for the subject in this
            %loop (2 sets of absorbance data for each subject because there
            %is data for the left and right ear)
        AbsorbanceSub_Male = [AbsorbanceSub_Male; Subject_Data.Absorbance(freq_rowM).'];
        end
        %create an array of all the absorbance data for all the male subjects
        Absorbance_Male = [Absorbance_Male; AbsorbanceSub_Male.'];
    end
    
end
%get the mean of the absorbance for female/male
mean_AbsFemale = nanmean(Absorbance_Female);
mean_AbsMale = nanmean(Absorbance_Male);


%%%get the mean Zmag for male and female subjects
Zmag_Female = [];
Zmag_Male = [];
%loop through all the subjects
for index=1:length(SubjectNumbers)
    SubNumForLoop = SubjectNumbers(index);
    %get the rows of the subject in the table
    sub_row = find(data.SubjectNumber == SubNumForLoop);
    %create a table of the subject's data each loop
    Subject_Data = data(sub_row,:);
    
    %if the subject number is in the list of female subject numbers, get
    %the female subject's data
    if sum(femalesubjectnums==SubNumForLoop) == 1
        ZmagSub_Female = [];
        %loop through the frequencies in the data
        for freq_indexF=1:length(Frequency)
            %get the frequency every loop
            FreqForLoopF = Frequency(freq_indexF);
            %get the rows in the subject's data that have that frequency
            freq_rowF = find(Subject_Data.Frequency == FreqForLoopF);
            %create an array of the Zmag data for the subject in this
            %loop (2 sets of absorbance data for each subject because there
            %is data for the left and right ear) also, the Zmag data type must
            %be converted from a cell to an integer
        ZmagSub_Female = [ZmagSub_Female; str2num(char(Subject_Data.Zmag(freq_rowF))).'];
        end
        %create an array of all the Zmag data for all the female subjects
        Zmag_Female = [Zmag_Female; ZmagSub_Female.'];
    %if the subject number is in the list of male subject numbers, get
    %the male subject's data
    elseif sum(malesubjectnums==SubNumForLoop) == 1
        ZmagSub_Male = [];
        %loop through the frequencies in the data
        for freq_indexM=1:length(Frequency)
            %get the frequency every loop
            FreqForLoopM = Frequency(freq_indexM);
            %get the rows in the subject's data that have that frequency
            freq_rowM = find(Subject_Data.Frequency == FreqForLoopM);
            %create an array of the Zmag data for the subject in this
            %loop (2 sets of absorbance data for each subject because there
            %is data for the left and right ear) also, the Zmag data type must
            %be converted from a cell to an integer
        ZmagSub_Male = [ZmagSub_Male; str2num(char(Subject_Data.Zmag(freq_rowM))).'];
        end
        %create an array of all the Zmag data for all the male subjects
        Zmag_Male = [Zmag_Male; ZmagSub_Male.'];
    end
    
end
%get the mean of the Zmag for female/male
mean_ZmagFemale = nanmean(Zmag_Female);
mean_ZmagMale = nanmean(Zmag_Male);


%%%get the mean Zang for male and female subjects
Zang_Female = [];
Zang_Male = [];
%loop through all the subjects
for index=1:length(SubjectNumbers)
    SubNumForLoop = SubjectNumbers(index);
    %get the rows of the subject in the table
    sub_row = find(data.SubjectNumber == SubNumForLoop);
    %create a table of the subject's data each loop
    Subject_Data = data(sub_row,:);
    
    %if the subject number is in the list of female subject numbers, get
    %the female subject's data
    if sum(femalesubjectnums==SubNumForLoop) == 1
        ZangSub_Female = [];
        %loop through the frequencies in the data
        for freq_indexF=1:length(Frequency)
            %get the frequency every loop
            FreqForLoopF = Frequency(freq_indexF);
            %get the rows in the subject's data that have that frequency
            freq_rowF = find(Subject_Data.Frequency == FreqForLoopF);
            %create an array of the Zang data for the subject in this
            %loop (2 sets of absorbance data for each subject because there
            %is data for the left and right ear) also, the Zang data type must
            %be converted from a cell to an integer
        ZangSub_Female = [ZangSub_Female; str2num(char(Subject_Data.Zang(freq_rowF))).'];
        end
        %create an array of all the Zang data for all the female subjects
        Zang_Female = [Zang_Female; ZangSub_Female.'];
    %if the subject number is in the list of male subject numbers, get
    %the male subject's data
    elseif sum(malesubjectnums==SubNumForLoop) == 1
        ZangSub_Male = [];
        %loop through the frequencies in the data
        for freq_indexM=1:length(Frequency)
            %get the frequency every loop
            FreqForLoopM = Frequency(freq_indexM);
            %get the rows in the subject's data that have that frequency
            freq_rowM = find(Subject_Data.Frequency == FreqForLoopM);
            %create an array of the Zang data for the subject in this
            %loop (2 sets of absorbance data for each subject because there
            %is data for the left and right ear) also, the Zang data type must
            %be converted from a cell to an integer
        ZangSub_Male = [ZangSub_Male; str2num(char(Subject_Data.Zang(freq_rowM))).'];
        end
        %create an array of all the Zang data for all the male subjects
        Zang_Male = [Zang_Male; ZangSub_Male.'];
    end
    
end
%get the mean of the Zang for female/male
mean_ZangFemale = nanmean(Zang_Female);
mean_ZangMale = nanmean(Zang_Male);

%plot the mean absorbanace, Zmag, and Zang for female and male subjects
figure(1)
set(gcf, 'Position', [100, 100, 400, 700]) %formats the size of the figure
subplot(311)
semilogx(Frequency, mean_AbsFemale,'c','LineWidth',2)
sgtitle('Rosowski et al. (2012)')
xlim([100 10000])
ylim([0 1])
xlabel('Frequency (Hz)')
ylabel('Absorbance')
hold on
semilogx(Frequency, mean_AbsMale,'k','LineWidth',2)
hold off
legend('Female', 'Male')
subplot(312)
loglog(Frequency, mean_ZmagFemale,'c','LineWidth',2)
sgtitle('Rosowski et al. (2012)')
xlim([100 10000])
xlabel('Frequency (Hz)')
ylabel('Impedance Magnitude (MKS Ohms)')
hold on
semilogx(Frequency, mean_ZmagMale,'k','LineWidth',2)
hold off
legend('Female', 'Male')
subplot(313)
semilogx(Frequency, mean_ZangFemale,'c','LineWidth',2)
sgtitle('Rosowski et al. (2012)')
xlim([100 10000])
xlabel('Frequency (Hz)')
ylabel('Impedance Angle (cycles)')
hold on
semilogx(Frequency, mean_ZangMale,'k','LineWidth',2)
hold off
legend('Female', 'Male')

